==> material-ui-shell-1.1.12.tgz: package/es/providers/Filter/store/selectors.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { numberField, textField, boolField, dateField, timeField } from 'material-ui-shell/lib/providers/Filter/fields';
export function getField(name, fields) {
  var field = false;
  fields.map(function (f) {
    var _f$type = f.type,
        type = _f$type === void 0 ? 'text' : _f$type;

    if (f.name === name) {
      var defaultProps = {};

      if (type === 'number') {
        defaultProps = _extends({}, numberField);
      } else if (type === 'text') {
        defaultProps = _extends({}, textField);
      } else if (type === 'bool') {
        defaultProps = _extends({}, boolField);
      } else if (type === 'time') {
        defaultProps = _extends({}, timeField);
      } else if (type === 'date') {
        defaultProps = _extends({}, dateField);
      }

      field = _extends(_extends({}, defaultProps), f);
    }

    return f;
  });
  return field;
}
export function getList(filter, list, fields) {
  if (filter === void 0) {
    filter = {};
  }

  if (list === void 0) {
    list = [];
  }

  if (fields === void 0) {
    fields = [];
  }

  var result = [].concat(list);
  var _filter = filter,
      _filter$queries = _filter.queries,
      queries = _filter$queries === void 0 ? [] : _filter$queries,
      sortFieldName = _filter.sortField,
      _filter$sortOrientati = _filter.sortOrientation,
      sortOrientation = _filter$sortOrientati === void 0 ? 1 : _filter$sortOrientati,
      _filter$search = _filter.search,
      search = _filter$search === void 0 ? {} : _filter$search;
  var _search$value = search.value,
      searchValue = _search$value === void 0 ? '' : _search$value;

  if (list == null || list.length < 1 || fields.length < 1) {
    return [];
  }

  result = result.filter(function (row, i) {
    var show = true;

    for (var _i = 0; _i < queries.length; _i++) {
      var q = queries[_i];
      var fieldName = q.field,
          _q$operator = q.operator,
          operator = _q$operator === void 0 ? '=' : _q$operator,
          value = q.value;
      var field = getField(fieldName, fields);

      if (field) {
        show = field.filter(row[fieldName], q);
      }

      if (!show) {
        return show;
      }
    }

    return show;
  });

  if (searchValue != null && searchValue !== '' && searchValue !== undefined) {
    result = result.filter(function (row) {
      return JSON.stringify(row).toUpperCase().indexOf(String(searchValue).toUpperCase()) !== -1;
    });
  }

  if (sortFieldName && sortFieldName !== '') {
    var sortField = getField(sortFieldName, fields);

    if (result !== undefined && sortField.sort !== undefined) {
      result.sort(function (a, b) {
        return sortField.sort(sortOrientation, a[sortFieldName], b[sortFieldName]);
      });
    }
  }

  return result;
}

==> material-ui-shell-1.1.18.tgz: package/es/providers/Filter/store/selectors.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import { numberField, textField, boolField, dateField, timeField } from 'material-ui-shell/lib/providers/Filter/fields';
export function getField(name, fields) {
  var field = false;
  fields.map(function (f) {
    var _f$type = f.type,
        type = _f$type === void 0 ? 'text' : _f$type;

    if (f.name === name) {
      var defaultProps = {};

      if (type === 'number') {
        defaultProps = _extends({}, numberField);
      } else if (type === 'text') {
        defaultProps = _extends({}, textField);
      } else if (type === 'bool') {
        defaultProps = _extends({}, boolField);
      } else if (type === 'time') {
        defaultProps = _extends({}, timeField);
      } else if (type === 'date') {
        defaultProps = _extends({}, dateField);
      }

      field = _extends(_extends({}, defaultProps), f);
    }

    return f;
  });
  return field;
}
export function getList(filter, list, fields) {
  if (filter === void 0) {
    filter = {};
  }

  if (list === void 0) {
    list = [];
  }

  if (fields === void 0) {
    fields = [];
  }

  var result = [].concat(list);
  var _filter = filter,
      _filter$queries = _filter.queries,
      queries = _filter$queries === void 0 ? [] : _filter$queries,
      sortFieldName = _filter.sortField,
      _filter$sortOrientati = _filter.sortOrientation,
      sortOrientation = _filter$sortOrientati === void 0 ? 1 : _filter$sortOrientati,
      _filter$search = _filter.search,
      search = _filter$search === void 0 ? {} : _filter$search;
  var _search$value = search.value,
      searchValue = _search$value === void 0 ? '' : _search$value;

  if (list == null || list.length < 1 || fields.length < 1) {
    return [];
  }

  result = result.filter(function (row) {
    var show = true;

    for (var i = 0; i < queries.length; i++) {
      var q = queries[i];
      var fieldName = q.field;
      var field = getField(fieldName, fields);

      if (field) {
        show = field.filter(row[fieldName], q);
      }

      if (!show) {
        return show;
      }
    }

    return show;
  });

  if (searchValue != null && searchValue !== '' && searchValue !== undefined) {
    result = result.filter(function (row) {
      return JSON.stringify(row).toUpperCase().indexOf(String(searchValue).toUpperCase()) !== -1;
    });
  }

  if (sortFieldName && sortFieldName !== '') {
    var sortField = getField(sortFieldName, fields);

    if (result !== undefined && sortField.sort !== undefined) {
      result.sort(function (a, b) {
        return sortField.sort(sortOrientation, a[sortFieldName], b[sortFieldName]);
      });
    }
  }

  return result;
}
